@@ -10,77 +10,82 @@
 package org.gnu.gdk;
 
 import org.gnu.glib.Boxed;
-import org.gnu.javagnome.Handle;
+import org.gnu.glib.Handle;
 
 /**
- *
+ * 
  */
-public class EventKey extends Event
-{
+public class EventKey extends Event {
     /**
-     * Promotion constructor. Construct the specific event object by
-     * promoting (sharing the <tt>Handle</tt> object of) the base
-     * <tt>Event</tt>.
+     * Promotion constructor. Construct the specific event object by promoting
+     * (sharing the <tt>Handle</tt> object of) the base <tt>Event</tt>.
      */
-    public EventKey( Event evt ) {
-        // We share the handle with both instances.  This avoids
+    public EventKey(Event evt) {
+        // We share the handle with both instances. This avoids
         // copying the event (via the constructor ( super( evt ) ).
         // It is more of a "promotion" constructor.
-        super( evt.getHandle() );
+        super(evt.getHandle());
     }
 
     public EventKey(Handle handle) {
         super(handle);
     }
-    
+
     public static EventKey getEventKey(Handle handle) {
         if (handle == null)
             return null;
-        
+
         EventKey obj = (EventKey) Boxed.getBoxedFromHandle(handle);
-        
+
         if (obj == null)
             obj = new EventKey(handle);
-        
+
         return obj;
     }
-	
+
     public int getKeyVal() {
         return EventKey.getKeyval(getHandle());
     }
-	
+
     public String getString() {
         return EventKey.getString(getHandle());
     }
-	
+
     public int getGroup() {
         return EventKey.getGroup(getHandle());
     }
-	
+
     public int getLength() {
         return EventKey.getLength(getHandle());
     }
-	
+
     public int getState() {
         return EventKey.getState(getHandle());
     }
-    
+
     public ModifierType getModifierKey() {
-        return ModifierType.intern( getState() );
+        return ModifierType.intern(getState());
     }
 
     public Window getWindow() {
         return Window.getWindowFromHandle(getWindow(getHandle()));
     }
-	
-    native static final protected Handle getWindow (Handle obj);
-    native static final protected boolean getSendEvent (Handle obj);
-    native static final protected int getTime (Handle obj);
-    native static final protected int getState (Handle obj);
-    native static final protected int getKeyval (Handle obj);
-    native static final protected int getLength (Handle obj);
-    native static final protected String getString (Handle obj);
-    native static final protected int getHardwareKeycode (Handle obj);
-    native static final protected int getGroup (Handle obj);
-}
 
+    native static final protected Handle getWindow(Handle obj);
+
+    native static final protected boolean getSendEvent(Handle obj);
+
+    native static final protected int getTime(Handle obj);
+
+    native static final protected int getState(Handle obj);
+
+    native static final protected int getKeyval(Handle obj);
+
+    native static final protected int getLength(Handle obj);
+
+    native static final protected String getString(Handle obj);
+
+    native static final protected int getHardwareKeycode(Handle obj);
+
+    native static final protected int getGroup(Handle obj);
+}
