@@ -12,19 +12,16 @@ package org.gnu.pango;
 import org.gnu.glib.Handle;
 
 /**
- * The PangoAttrInt object is used to represent attributes with a integer
- * value
+ * The PangoAttrInt object is used to represent attributes with a integer value
  */
-public class AttrInt extends Attribute 
-{
+public class AttrInt extends Attribute {
 
-	/**
-	 * Returns the value of the object.
-	 */
-	public int getValue(){
-		return getValue(getHandle());
-	}
+    /**
+     * Returns the value of the object.
+     */
+    public int getValue() {
+        return getValue(getHandle());
+    }
 
-    native static final protected int getValue (Handle obj);
+    native static final protected int getValue(Handle obj);
 }
-
