@@ -13,6 +13,7 @@
 #include <jg_jnu.h>
 #include "gtk_java.h"
 
+#include "org_gnu_gtk_TreeModelFilter.h"
 #ifdef __cplusplus
 extern "C" 
 {
@@ -33,7 +34,7 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gtk_TreeModelFilter_gtk_1tree_1model_1fil
     return getGObjectHandle(env, (GObject *) gtk_tree_model_filter_new(model_g, root_g));
 }
 
-gboolean static treeModelFilterVisibleFunc(GtkTreeModel *model,
+static gboolean treeModelFilterVisibleFunc(GtkTreeModel *model,
 		GtkTreeIter *iter, gpointer data)
 {
 	jobject model_handle;
